@@ -14,7 +14,7 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Bool Str ArrayRef FileHandle);
 use Params::Validate qw(validate_with SCALAR ARRAYREF);
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 const my $INTEGER_LENGTH     => length pack 'N', 0;
 const my $REVISION_OFFSET    => $INTEGER_LENGTH;
@@ -158,11 +158,11 @@ sub _unpack_message {
     my %message;
 
     # split original
-    my @strings = split $CONTEXT_SEPARATOR, $msgid;
+    my @strings = split m{ \Q$CONTEXT_SEPARATOR\E }xms, $msgid;
     if ( @strings > 1 ) {
         ( $message{msgctxt}, $msgid ) = @strings;
     }
-    my @plurals = split $PLURAL_SEPARATOR, $msgid;
+    my @plurals = split m{ \Q$PLURAL_SEPARATOR\E }xms, $msgid;
     my $is_plural = @plurals > 1;
     if ( $is_plural ) {
         @message{qw(msgid msgid_plural)} = @plurals;
@@ -173,10 +173,10 @@ sub _unpack_message {
 
     # split translation
     @plurals = split
-        $PLURAL_SEPARATOR,
+        m{ \Q$PLURAL_SEPARATOR\E }xms,
         $msgstr,
         # get back also all hanging empty stings
-        1 + $msgstr =~ m{\Q$PLURAL_SEPARATOR\E}xms;
+        1 + do { my @separators = $msgstr =~ m{ \Q$PLURAL_SEPARATOR\E }xmsg };
     if ( $is_plural ) {
         $message{msgstr_plural} = \@plurals;
     }
@@ -402,13 +402,13 @@ __END__
 
 Locale::MO::File - Write/read gettext MO files
 
-$Id: File.pm 636 2015-04-26 19:21:20Z steffenw $
+$Id: File.pm 638 2017-10-01 19:05:33Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/dbd-po/code/Locale-MO-File/trunk/lib/Locale/MO/File.pm $
 
 =head1 VERSION
 
-0.07
+0.08
 
 =head1 SYNOPSIS
 
